@@ -1,10 +1,13 @@
 recluster.cons <- function(mat,phylo=NULL,tr=100,p=0.5,dist="simpson", method="average", blenghts=TRUE, select=FALSE) {
-	sampl<-cbind((1:nrow(mat))+10,rownames(mat))
-	distance<-recluster.dist(mat,phylo,dist)
-	res<-NULL	
-	trees<-NULL
-	RSS<-NULL
-		for (i in 1 : tr){
+      if(data.class(mat)=="dist")
+      {distance<-mat}
+      else
+      {distance<-recluster.dist(mat,phylo,dist)}
+      sampl<-cbind((1:nrow(as.matrix(distance)))+10,rownames(as.matrix(distance)))
+      res<-NULL	
+      trees<-NULL
+      RSS<-NULL
+      for (i in 1 : tr){
 		dist1<-as.matrix(distance)		
 		sampl[,1]<-sample(1:nrow(sampl))+10
 		rownames(dist1)<-sampl[,1]
