@@ -5,7 +5,7 @@ recluster.dist <-function(mat, phylo=NULL, dist="simpson") {
 	if(prod(rowSums(mat)) == 0) stop("ERROR: empty site(s) in matrix")
 	#if(prod(colSums(mat)) == 0) stop("ERROR: species with 0 occurrence in matrix")
 
-	options<-c("simpson","sorensen","nestedness","beta3","richness","jaccard","phylosor","phylosort","phylosorpd","unifrac","unifract","unifracpd")
+	options<-c("simpson","sorensen","nestedness","beta3","richness","jaccard","jturnover","jnestedness","phylosor","phylosort","phylosorpd","unifrac","unifract","unifracpd")
 	if (is.na(pmatch(dist[1],options))) {
 			res <- designdist(mat, method = dist,terms = c("binary"))
 			attr(res,"dist") <- dist
@@ -30,6 +30,16 @@ recluster.dist <-function(mat, phylo=NULL, dist="simpson") {
 			attr(res,"dist") <- "jaccard"
 			res
 		},
+		jturnover = {
+			res <- designdist(mat, method = "2*(pmin(A,B)-J)/(J+2*(pmin(A,B)-J))",terms = c("binary"))
+			attr(res,"dist") <- "jturnover"
+			res
+		},
+		jnestedness = {
+			res <- designdist(mat, method = "(((pmax(A,B)-J)-(pmin(A,B)-J))/(A+B-J))*(J/(J+2*(pmin(A,B)-J)))",terms = c("binary"))
+			attr(res,"dist") <- "jnestedness"
+			res
+		},
 		sorensen = {
 			res <- designdist(mat, method = "(A+B-2*J)/(A+B)",terms = c("binary"))
 			attr(res,"dist") <- "sorensen"
